@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2020 S[&]T, The Netherlands.
+ * Copyright (C) 2007-2021 S[&]T, The Netherlands.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -149,7 +149,7 @@ static int get_attribute_value(const coda_hdf4_product *product, coda_hdf4_attri
         return 0;
     }
     attribute = attributes->attribute[index];
-    if (attribute->definition->type_class != coda_integer_class || attribute->definition->type_class != coda_real_class)
+    if (attribute->definition->type_class != coda_integer_class && attribute->definition->type_class != coda_real_class)
     {
         return 0;
     }
